@@ -41,7 +41,7 @@ class UIWindow(tk.Tk):
     def __init__(self, radio_dir=None, settings_path=None):
         super().__init__()
         self.list_e = []
-        self.gr_version = '0.6.6'
+        self.gr_version = '0.6.8'
         self.radio_dir = radio_dir
         self.settings_path = settings_path
 
@@ -137,7 +137,7 @@ class UIWindow(tk.Tk):
                                     width=10, padx=2, pady=1, command=UItextEditor)
         self.btn_stop = tk.Button(master=self.btm_frame, text="Stop", width=10, padx=2, pady=1, command=self.exit_app)
         self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10,
-                                 padx=2, pady=1, command=self.list_checked)
+                                 padx=2, pady=1, command=self.run_app)
         self.lbl_info = tk.Label(master=self.btm_frame, bg='azure3', anchor="s")
 
         # bottom grid
@@ -238,7 +238,7 @@ class UIWindow(tk.Tk):
     def exit_app(self):
         term.GBase.exit_app = True
         sleep(term.GBase.sleeper + 1)  # threads sleep too, time for exit
-        self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10, command=self.list_checked)
+        self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10, command=self.run_app)
         self.btn_rec.grid(row=0, column=3, sticky='w')
         term.GBase.exit_app = False
 
@@ -303,7 +303,7 @@ class UIWindow(tk.Tk):
             tk.Checkbutton(frame, variable=self.box_list[-1],
                            command=self.cb_checked, bg='azure3').grid(row=idx + 2, column=2, sticky='e')
 
-    def list_checked(self):
+    def run_app(self):
 
         term.GBase.pool.submit(self.display_info_text)
 
@@ -373,6 +373,7 @@ class UIWindow(tk.Tk):
         term.GBase.pool.submit(term.GRecorder.thread_pull_song_name, url, key)
         term.GBase.pool.submit(term.GRecorder.ghetto_recorder_head, dir_save, stream_suffix, key)
         term.GBase.pool.submit(term.GRecorder.ghetto_recorder_tail, url, key, dir_save)
+        term.GBase.pool.submit(term.GRecorder.get_metadata_from_stream_loop, url, key)
 
     def display_title(self):
 
@@ -429,14 +430,14 @@ class UIWindow(tk.Tk):
         term.GBase.exit_app = True
         sleep(term.GBase.sleeper + 1)  # threads sleep too, give time for exit, reset exit_app
         term.GBase.exit_app = False
-        self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10, command=self.list_checked)
+        self.btn_rec = tk.Button(master=self.btm_frame, text="Record", width=10, command=self.run_app)
         self.btn_rec.grid(row=0, column=3, sticky='w')
 
     def progress(self, current_timer, max_value):
         # progressbar['value'] = 20 , is the percentage from 100, combobox returns string value
         # doing some math, p = (P * 100) / G, percent = (math.percentage value * 100) / base
         cur_percent = round((current_timer * 100) / max_value, 0)
-        # print(f'cur_percent {cur_percent}  current_timer {current_timer} max {max_value}')
+        # print(f' cur_percent {cur_percent}  current_timer {current_timer} max {max_value}')
         self.progressbar['value'] = cur_percent
         self.update_idletasks()
         sleep(1)
